@@ -7,7 +7,6 @@ from watchdog.events import FileSystemEventHandler
 from watchdog.observers import Observer
 from isass.helpers import get_source_dirs,get_source_files,distinct,split_paths
 from isass import SassCompiler
-from pymlconf import ConfigManager
 import os.path
 from isass.manifest import Manifest
 
@@ -57,7 +56,7 @@ class SassObserver(Observer):
         handler = IsassEventHandler(outfile, dirs,lib_dirs=lib_dirs)
         handler.write_out()
         for d in dirs:
-            self.schedule(handler, d, recursive=True)
+            self.schedule(handler, d, recursive=False)
 
     def add_manifest(self,manifest):
         manifest = Manifest(manifest)
